==> nhc98src-1.18.tar.gz: nhc98-1.18/src/libraries/base/Debug/Trace.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v185	((void*)startLabel+32)
#define CT_v187	((void*)startLabel+104)
#define ST_v183	((void*)startLabel+136)
#define ST_v184	((void*)startLabel+148)
#define ST_v186	((void*)startLabel+172)
extern Node TM_Debug_46Trace[];
extern Node FN_IO_46hPutStrLn[];
extern Node CF_IO_46stderr[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62[];
extern Node FN_Prelude_46_36[];
extern Node F0_NHC_46Internal_46unsafePerformIO[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v185)
,};
Node FN_Debug_46Trace_46putTraceMsg[] = {
  useLabel(TM_Debug_46Trace)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 350001
, useLabel(ST_v184)
,	/* CT_v185: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Debug_46Trace_46putTraceMsg[] = {
  CAPTAG(useLabel(FN_Debug_46Trace_46putTraceMsg),1)
, VAPTAG(useLabel(FN_IO_46hPutStrLn))
, useLabel(CF_IO_46stderr)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v187)
,};
Node FN_Debug_46Trace_46trace[] = {
  useLabel(TM_Debug_46Trace)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
, bytes2word(HEAP_CVAL_I4,HEAP_ARG,2,HEAP_CVAL_I5)
, bytes2word(HEAP_OFF_N1,5,HEAP_OFF_N1,4)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,6,HEAP_CVAL_P1)
, bytes2word(7,HEAP_OFF_N1,5,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 560001
, useLabel(ST_v186)
,	/* CT_v187: (byte 0) */
  HW(5,2)
, 0
,};
Node F0_Debug_46Trace_46trace[] = {
  CAPTAG(useLabel(FN_Debug_46Trace_46trace),2)
, VAPTAG(useLabel(FN_Debug_46Trace_46putTraceMsg))
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62))
, VAPTAG(useLabel(FN_Prelude_46_36))
, useLabel(F0_NHC_46Internal_46unsafePerformIO)
,};
Node PM_Debug_46Trace[] = {
 	/* ST_v183: (byte 0) */
  bytes2word(68,101,98,117)
, bytes2word(103,46,84,114)
,	/* ST_v184: (byte 4) */
  bytes2word(97,99,101,0)
, bytes2word(68,101,98,117)
, bytes2word(103,46,84,114)
, bytes2word(97,99,101,46)
, bytes2word(112,117,116,84)
, bytes2word(114,97,99,101)
,	/* ST_v186: (byte 4) */
  bytes2word(77,115,103,0)
, bytes2word(68,101,98,117)
, bytes2word(103,46,84,114)
, bytes2word(97,99,101,46)
, bytes2word(116,114,97,99)
, bytes2word(101,0,0,0)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/libraries/base/Debug/Trace.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v207	((void*)startLabel+32)
#define CT_v209	((void*)startLabel+104)
#define FN_Debug_46Trace_46traceShow	((void*)startLabel+144)
#define CT_v211	((void*)startLabel+172)
#define F0_Debug_46Trace_46traceShow	((void*)startLabel+180)
#define ST_v205	((void*)startLabel+196)
#define ST_v206	((void*)startLabel+208)
#define ST_v208	((void*)startLabel+232)
#define ST_v210	((void*)startLabel+250)
extern Node TM_Debug_46Trace[];
extern Node FN_IO_46hPutStrLn[];
extern Node CF_IO_46stderr[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62[];
extern Node FN_Prelude_46_36[];
extern Node F0_NHC_46Internal_46unsafePerformIO[];
extern Node FN_Prelude_46show[];
extern Node FN_Prelude_46_46[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v207)
,};
Node FN_Debug_46Trace_46putTraceMsg[] = {
  useLabel(TM_Debug_46Trace)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(HEAP_ARG,1,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 350001
, useLabel(ST_v206)
,	/* CT_v207: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Debug_46Trace_46putTraceMsg[] = {
  CAPTAG(useLabel(FN_Debug_46Trace_46putTraceMsg),1)
, VAPTAG(useLabel(FN_IO_46hPutStrLn))
, useLabel(CF_IO_46stderr)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v209)
,};
Node FN_Debug_46Trace_46trace[] = {
  useLabel(TM_Debug_46Trace)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
, bytes2word(HEAP_CVAL_I4,HEAP_ARG,2,HEAP_CVAL_I5)
, bytes2word(HEAP_OFF_N1,5,HEAP_OFF_N1,4)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,6,HEAP_CVAL_P1)
, bytes2word(7,HEAP_OFF_N1,5,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 570001
, useLabel(ST_v208)
,	/* CT_v209: (byte 0) */
  HW(5,2)
, 0
,};
Node F0_Debug_46Trace_46trace[] = {
  CAPTAG(useLabel(FN_Debug_46Trace_46trace),2)
, VAPTAG(useLabel(FN_Debug_46Trace_46putTraceMsg))
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62))
, VAPTAG(useLabel(FN_Prelude_46_36))
, useLabel(F0_NHC_46Internal_46unsafePerformIO)
, bytes2word(1,0,0,1)
, useLabel(CT_v211)
,	/* FN_Debug_46Trace_46traceShow: (byte 0) */
  useLabel(TM_Debug_46Trace)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,1)
, bytes2word(PUSH_HEAP,HEAP_CVAL_I4,HEAP_CVAL_I5,HEAP_OFF_N1)
, bytes2word(4,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 670001
, useLabel(ST_v210)
,	/* CT_v211: (byte 0) */
  HW(3,1)
, 0
,	/* F0_Debug_46Trace_46traceShow: (byte 0) */
  CAPTAG(useLabel(FN_Debug_46Trace_46traceShow),1)
, VAPTAG(useLabel(FN_Prelude_46show))
, VAPTAG(useLabel(FN_Prelude_46_46))
, useLabel(F0_Debug_46Trace_46trace)
,};
Node PM_Debug_46Trace[] = {
 	/* ST_v205: (byte 0) */
  bytes2word(68,101,98,117)
, bytes2word(103,46,84,114)
,	/* ST_v206: (byte 4) */
  bytes2word(97,99,101,0)
, bytes2word(68,101,98,117)
, bytes2word(103,46,84,114)
, bytes2word(97,99,101,46)
, bytes2word(112,117,116,84)
, bytes2word(114,97,99,101)
,	/* ST_v208: (byte 4) */
  bytes2word(77,115,103,0)
, bytes2word(68,101,98,117)
, bytes2word(103,46,84,114)
, bytes2word(97,99,101,46)
, bytes2word(116,114,97,99)
,	/* ST_v210: (byte 2) */
  bytes2word(101,0,68,101)
, bytes2word(98,117,103,46)
, bytes2word(84,114,97,99)
, bytes2word(101,46,116,114)
, bytes2word(97,99,101,83)
, bytes2word(104,111,119,0)
,};
